# Django Userena (Community Edition)

> **DEPRECATED**: This project is no longer maintained and will not receive any
> further updates or security fixes. Please find an alternative package for
> user management. Consider using
> [django-allauth](https://github.com/pennersr/django-allauth) as a
> replacement.
